pub fn create_router(manager: Arc<CellManager>) -> RouterExpand description
Build the Axum router that exposes the cellz HTTP, SSE, and WebSocket API.
pub fn create_router(manager: Arc<CellManager>) -> RouterBuild the Axum router that exposes the cellz HTTP, SSE, and WebSocket API.